@@ -43,6 +43,17 @@ class Assets:
                     )
                     print(f"File ==> {path} is {kind}")
 
+    def find(self, path=None):
+        current_file = self.manager.get_path(path)
+        if current_file is None:
+            print("Missing file path")
+            return
+        try:
+            token = self.manager.get_value(current_file, False)
+            return self.manager.proxy_url(self.role, token)
+        except:  # noqa: E722
+            return None
+
     def add(self, path=None, params={}, debug=False):
         current_file = self.manager.get_path(path)
         if current_file is None:
