@@ -4,6 +4,7 @@ import requests
 import os
 
 __jup_def_set_workspace = "/etc/naas/set_workspace.json"
+__jup_def_set_workspace_browser = "/etc/naas/set_workspace_browser.json"
 __jup_load_workspace = "jupyter lab workspaces import "
 __github_repo = "jupyter-naas/starters"
 __github_brach = "main"
@@ -13,21 +14,48 @@ __github_base_url = "https://github.com/{REPO}/blob/{BRANCH}/"
 
 def download_file(url):
     raw_target = url
+    file_name = raw_target.split("/")[-1]
+    file_name = urllib.parse.unquote(file_name)
+    file_name = f"dl_{file_name}"
     if "github.com" in raw_target:
         raw_target = raw_target.replace(
             "https://github.com/", "https://raw.githubusercontent.com/"
         )
         raw_target = raw_target.replace("/blob/", "/")
-    r = requests.get(raw_target)
-
-    file_name = raw_target.split("/")[-1]
-    file_name = urllib.parse.unquote(file_name)
+    content = b"ERROR"
+    if "://" not in raw_target and raw_target.startswith(".naas"):
+        try:
+            cur_path = os.path.join(n_env.server_root, raw_target)
+            ff = open(cur_path, "rb")
+            content = ff.read()
+            ff.close()
+        except Exception as e:
+            print("Cannot open local file", e)
+    else:
+        r = requests.get(raw_target)
+        content = r.content
 
     with open(file_name, "wb") as f:
-        f.write(r.content)
+        f.write(content)
+        f.close()
     return file_name
 
 
+def wp_set_for_open_filebrowser(url):
+    try:
+        filename = url.split("/")[-1]
+        filename = filename.split(".")[0]
+        new_wp = os.path.join(n_env.path_naas_folder, f"{filename}_workspace.json")
+        with open(__jup_def_set_workspace_browser, "r") as fh:
+            content_wp = fh.read()
+            new_content_wp = content_wp.replace("{NB_NAME}", filename)
+            with open(new_wp, "w+") as f:
+                f.write(new_content_wp)
+        os.system(f"{__jup_load_workspace} {new_wp}")
+    except Exception as e:
+        print("Cannot config jupyter workspace", e)
+
+
 def __wp_set_for_open(url):
     try:
         filename_full = url.split("/")[-1]
